Each case and matched controls form a stratum in the data set. This function is to calculate the pooled OR for the data set.
calc_strata_or(dfs, filter = TRUE, filterdata = NULL)A named list of dataframes created by package functions
Filter statement to apply
Extra data to left join to the dfs for filtering
Uses the M-H method unless there is only one strata for which the
fisher.test is used. For more information, please refer to the vignette
using browseVignettes("nncc").